Class: common_metadata - LinkML Model

# Class: common_metadata

Generic metadata shared across definitions

URI: linkml:CommonMetadata

## Mixin for

- Element (mixin) - a named element in the model
- PermissibleValue (mixin) - a permissible value, accompanied by intended text and an optional mapping to a concept URI

## Referenced by Class

## Attributes

### Own

- description 0..1
  - Description: a description of the element's purpose and use
  - Range: String
  - in subsets: (owl)
- alt_descriptions 0..*
  - Range: AltDescription
- deprecated 0..1
  - Description: Description of why and when this element will no longer be used
  - Range: String
- todos 0..*
  - Description: Outstanding issue that needs resolution
  - Range: String
- notes 0..*
  - Description: editorial notes about an element intended for internal consumption
  - Range: String
  - in subsets: (owl)
- comments 0..*
  - Description: notes and comments about an element intended for external consumption
  - Range: String
  - in subsets: (owl)
- examples 0..*
  - Description: example usages of an element
  - Range: Example
  - in subsets: (owl)
- in_subset 0..*
  - Description: used to indicate membership of a term in a defined subset of terms used for a particular domain or application (e.g. the translator_minimal subset holding the minimal set of predicates used in a translator knowledge graph)
  - Range: SubsetDefinition
- from_schema 0..1
  - Description: id of the schema that defined the element
  - Range: Uri
- imported_from 0..1
  - Description: the imports entry that this element was derived from. Empty means primary source
  - Range: String
- see_also 0..*
  - Description: a reference
  - Range: Uriorcurie
  - in subsets: (owl)
- deprecated element has exact replacement 0..1
  - Description: When an element is deprecated, it can be automatically replaced by this uri or curie
  - Range: Uriorcurie
- deprecated element has possible replacement 0..1
  - Description: When an element is deprecated, it can be potentially replaced by this uri or curie
  - Range: Uriorcurie